% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/LH_sample.R
\name{LH_sample}
\alias{LH_sample}
\title{LH_sample}
\usage{
LH_sample <- function(sim_output, n_boots, samp_size, sample_type, supp_large = FALSE, supp_large_n_per_bin = 3, supp_small = FALSE, supp_small_n_per_bin = 3, supp_min_length = 2, constrained = FALSE, t0 = 0, SD_L_const = TRUE, save_bootstraps = FALSE, Amax = NULL, age_max = NULL, Lbin_width = 2)
}
\arguments{
\item{sim_output}{output from simulate_population_harvest()}

\item{n_boots}{number of bootstraps for von Bertalanffy growth function}

\item{sample_type}{The sampling strategy to be used, either proportional otolith sampling (‘POS’) or fixed otolith sampling (‘FOS’)}

\item{supp_large}{TRUE / FALSE specifying whether supplemental samples will be collected from large length bins}

\item{supp_large_n_per_bin}{The number of samples per length bin to be collected from large bins (ignored if supp_large = FALSE)}

\item{supp_small}{TRUE / FALSE specifying whether supplemental samples will be collected from small length bins}

\item{supp_small_n_per_bin}{The number of samples per length bin to be collected from small bins (ignored if supp_small = FALSE)}

\item{supp_min_length}{The minimum length fish that could be collected from the wild fish population}

\item{constrained}{TRUE / FALSE specifying whether theoretical time at length zero (t0) should be estimated}

\item{t0}{If constrained = TRUE, the fixed value for t0 (typically 0)}

\item{SD_L_const}{TRUE / FALSE describing assumptions of population variance in length at age. If TRUE, then standard deviation (√𝜎𝜎2) of length at age is assumed a linear function of age. If FALSE, then the coefficient of variation of length at age is assumed a linear function of age.}

\item{save_bootstraps}{TRUE / FALSE specifying whether all bootstrap samples will be included in the function output}

\item{Amax}{Maximum longevity (years). If not specified, this value is taken from sim_output.}

\item{age_max}{An arbitrary age selected to represent “old” fish (years). If not specified, this value is taken from sim_output.}

\item{Lbin_width}{The width of each length bin (cm).}
}
\description{
A bootstrap sampling routine to estimate life history parameters from fishery catches simulated by simulate_population_harvest(). This function will take n_boots samples (without replacement) from the harvested individuals following either a fixed otolith sampling (FOS) or proportional otolith sampling (POS) strategy. The function then parameterizes the von Bertalanffy growth function and estimates the population coefficient of variation of length at age for each bootstrap sample.
}
\keyword{function}
